import React, {useState, useEffect } from "react";
import { Switch, Route, withRouter } from "react-router-dom";
import { connect } from "react-redux";

import { getAllEvents } from "./actions/getAllEvents";

import AdminMainPage from './conteiners/adminMainPage/adminMainPage';
import AdminAddEventPage from './conteiners/adminAddEventPage/adminAddEventPage';
import AdminMyEventsPage from './conteiners/adminMyEventsPage/adminMyEventsPage';
import AdminAddPhotogalarytPage from "./conteiners/adminPhotogalaryPage/adminPhotogalaryPage"

import Home from './conteiners/home/Home';
import Result from './conteiners/result/Result';
import Gallery from './conteiners/gallery/Gallery';
import Reviews from './conteiners/reviews/Reviews';
import Login from './conteiners/login/Login';
import RegistrationPage from './conteiners/registrationPage/RegistrationPage';
import Events from './conteiners/events/Events';
import EventCard from './conteiners/eventCard/EventCard';

import Profile from './conteiners/profile/Profile';

import { PrivateRoute } from "./private-router";

const PAGENOTFOUND = () => <div>PAGE 404 NOT FOUND</div>;

const route = [
	{
		id: 1,
		exact: true,
		path: "/",
		protected: false,
		component: Home,
		events: true
	},
	{
		id: 2,
		exact: true,
		path: "/events",
		protected: false,
		component: Events
	},
	{
		id: 3,
		exact: true,
		path: "/result",
		protected: true,
		component: Result
	},
	{
		id: 4,
		exact: true,
		path: "/gallery",
		protected: false,
		component: Gallery
    },
    {
		id: 5,
		exact: true,
		path: "/reviews",
		protected: false,
		component: Reviews
    },
    {
		id: 6,
		exact: true,
		path: "/login",
		protected: false,
		component: Login
    },
    {
		id: 7,
		exact: true,
		path: "/registration",
		protected: false,
		component: RegistrationPage
    },
    {
		id: 8,
		exact: true,
		path: "/profile",
        protected: true,
        hasAccess: 'user',
		component: Profile
    },
    {
		id: 9,
		exact: true,
		path: "/admin",
        protected: true,
        hasAccess: 'admin',
		component: AdminMainPage
    },
    {
		id: 10,
		exact: true,
		path: "/admin/add_new_event",
        protected: true,
        hasAccess: 'admin',
		component: AdminAddEventPage
    },
    {
		id: 11,
		exact: true,
		path: "/admin/photogalary",
        protected: true,
        hasAccess: 'admin',
		component: AdminAddPhotogalarytPage
    },
    {
		id: 12,
		exact: true,
		path: "/admin/my_events",
        protected: true,
        hasAccess: 'admin',
		component: AdminMyEventsPage
	},
	{
		id: 4,
		component: PAGENOTFOUND
	}
];

// export const Router = withRouter(({ history }) => {

// 	const [events, setEvents] = useState([]);

// 	useEffect(() => {
// 		fetch("https://api-marathon.herokuapp.com/api/v1/event")
// 			.then(response => response.json())
// 			.then(json => setEvents(json));
// 	}, []);

// 	console.log('events', events)

// 	useEffect(() => {
// 		const user = localStorage.getItem("user");
// 		if (user) {
// 			const userRole = JSON.parse(user).role;
// 			if (userRole === 'admin') {
// 				history.push("/admin");
//             }
//             if (userRole === 'user') {
// 				history.push("/profile");
// 			}
// 		}
// 	}, [history]);

// 	return (
// 		<div className="container">
// 			{console.log('events', events)}
// 			<Switch>
// 				{route.map(el => (
// 					<PrivateRoute
// 						protectedRoute={el.protected}
// 						key={el.id}
// 						exact={el.exact}
// 						path={el.path}
//                         component={el.component}
//                         events = {el.events && events}
// 					/>
// 				))}
				
// 				{
// 					events.map(event =>
// 						<Route exact
// 							path={`/events/${event._id}`}
// 							key={event._id}
// 							render={ props => (<EventCard event={event} />) }
// 						/>                            
// 					)
// 				}
// 			</Switch>
// 		</div>
// 	);
// });

export class Router extends React.Component {
    componentDidMount() {
        this.props.getAllEvents();
    }

    render() {
        const { events } = this.props;
		return(
			<div className="container">
			    <Switch>
                    <Route exact path="/" render={ props => (
                        <Home events={events} />
                    )} />

                    <Route exact path="/events" render={ props => (
                        <Events events={events} />
                    )} />

                    <Route exact path="/result" component={Result} />
                    <Route exact path="/gallery" component={Gallery} />
                    <Route exact path="/reviews" component={Reviews} />

                    {
                        events.map(event =>
                            <Route exact
                                path={`/events/${event._id}`}
                                key={event._id}
                                render={ props => (<EventCard event={event} />) }
                            />                            
                        )
                    }

                    <Route exact path="/login" component={Login} />
                    <Route exact path="/registration" component={RegistrationPage} />

                    <Route exact path="/profile" component={Profile} />
                    
			           
			        <Route exact path = '/admin' component = {AdminMainPage} />
			        <Route exact path = '/admin/add_new_event' component = {AdminAddEventPage} />
			        <Route exact path = '/admin/photogalary' component = {AdminAddPhotogalarytPage} />
					<Route exact path = '/admin/my_events' component = {AdminMyEventsPage} />
			            
			    </Switch>
			</div>
		)
	}
}

const mapStateToProps = state => {
    return {
        events: state.getEvents.events
    };
};

export default connect(
    mapStateToProps,
    { getAllEvents }
)(Router);